//*****************************************************//
//
// Unit: RsRegistry.cpp
//
// Purpose: Encapsulation of TRegIniFile for registry
//           manipulation
//
// Inherits From: TComponent
//
// Project: RapidMisc
//
// Author: Jeff Hiscock -- jhiscock@rapidsi.com
//
// Date: March 2000
//
// Revisions
//
// Copyright Rapid Systems 2000
//******************************************************//
//---------------------------------------------------------------------------
#include <vcl.h>
#pragma hdrstop

#include "RsRegistry.h"
#pragma package(smart_init)
//---------------------------------------------------------------------------
// ValidCtrCheck is used to assure that the components created do not have
// any pure virtual functions.
//

static inline void ValidCtrCheck(TRsRegistry *)
{
        new TRsRegistry(NULL);
}
//---------------------------------------------------------------------------
__fastcall TRsRegistry::TRsRegistry(TComponent* Owner)
        : TComponent(Owner)
{
  BaseKey = "\\Software\\Rapid\\";

}
//---------------------------------------------------------------------------
namespace Rsregistry
{
        void __fastcall PACKAGE Register()
        {
                 TComponentClass classes[1] = {__classid(TRsRegistry)};
                 RegisterComponents("Rapid - Misc", classes, 0);
        }
}
//---------------------------------------------------------------------------
String TRsRegistry::ReadString()
{
    //TODO: Add your source code here
    TRegIniFile *f = new TRegIniFile("");
    String s="";
    if (f->OpenKey(FBaseKey ,false))
    {
        try
        {
          s = f->ReadString (FTargetKey , FTargetValue , "None");
        }
        catch (Exception &e)
        {
            if (FOnReadError)
               FOnReadError(this);
            else
            {
               delete f;
               f = NULL;
               throw e;
            }
        }
    }
    else
    {
        if (FOnReadError)
           FOnReadError(this);
        else
        {
           delete f;
           f = NULL;
           throw Exception("Cannot open key to read");
        }

    }

    delete f;
    f = NULL;

    return s;




}


bool TRsRegistry::WriteString(String Value)
{
    //TODO: Add your source code here
    TRegIniFile *f = new TRegIniFile("");
    bool ok =false;

     if (f->OpenKey(FBaseKey ,!FDontCreate))
     {

         try
         {
           f->WriteString( FTargetKey , FTargetValue , Value);
           ok = true;
         }
         catch (Exception &e)
         {
            if (FOnReadError)
               FOnReadError(this);
            else
            {
               delete f;
               f = NULL;
               throw e;
            }
         }
    }
    else
    {
        if (FOnReadError)
           FOnReadError(this);
        else
        {
           delete f;
           f = NULL;
           throw Exception("Cannot open key to write");
        }

    }

    delete f;
    f = NULL;

    return ok;


}

bool __fastcall TRsRegistry::ReadBool()
{
    //TODO: Add your source code here
    TRegIniFile *f = new TRegIniFile("");
    bool ret;
    if (f->OpenKey(FBaseKey ,false))
    {
        try
        {
          ret = f->ReadBool (FTargetKey , FTargetValue , false);
        }
        catch (Exception &e)
        {
            if (FOnReadError)
               FOnReadError(this);
            else
            {
               delete f;
               f = NULL;
               throw e;
            }
        }
    }
    else
    {
        if (FOnReadError)
           FOnReadError(this);
        else
        {
           delete f;
           f = NULL;
           throw Exception("Cannot open key to read");
        }

    }

    delete f;
    f = NULL;

    return ret;

}


int __fastcall TRsRegistry::ReadInteger()
{
    //TODO: Add your source code here
     TRegIniFile *f = new TRegIniFile("");
    int ret;
    if (f->OpenKey(FBaseKey ,false))
    {
        try
        {
          ret = f->ReadInteger (FTargetKey , FTargetValue , -1);
        }
        catch (Exception &e)
        {
            if (FOnReadError)
               FOnReadError(this);
            else
            {
               delete f;
               f = NULL;
               throw e;
            }
        }
    }
    else
    {
        if (FOnReadError)
           FOnReadError(this);
        else
        {
           delete f;
           f = NULL;
           throw Exception("Cannot open key to read");
        }

    }

    delete f;
    f = NULL;

    return ret;
}


void __fastcall TRsRegistry::ReadSection(TStringList* retvals)
{
    //TODO: Add your source code here
    if (retvals ==NULL)
    {
       if (FOnReadError)
       {
          FOnReadError(this);
          return;
       }
       else
          throw Exception("RsRegistry - Read Section retvals is NULL");
    }

    TRegIniFile *f = new TRegIniFile("");

    if (f->OpenKey(FBaseKey ,false))
    {
        try
        {
          f->ReadSection (FTargetKey ,retvals);
        }
        catch (Exception &e)
        {
            if (FOnReadError)
               FOnReadError(this);
            else
            {
               delete f;
               f = NULL;
               throw e;
            }
        }
    }
    else
    {
        if (FOnReadError)
           FOnReadError(this);
        else
        {
           delete f;
           f = NULL;
           throw Exception("Cannot open key to read");
        }

    }

    delete f;
    f = NULL;


}


bool __fastcall TRsRegistry::WriteBool(bool value)
{
    //TODO: Add your source code here
    TRegIniFile *f = new TRegIniFile("");
    bool ok =false;

     if (f->OpenKey(FBaseKey ,!FDontCreate))
     {

         try
         {
           f->WriteBool( FTargetKey , FTargetValue , value);
           ok = true;
         }
         catch (Exception &e)
         {
            if (FOnReadError)
               FOnReadError(this);
            else
            {
               delete f;
               f = NULL;
               throw e;
            }
         }
    }
    else
    {
        if (FOnReadError)
           FOnReadError(this);
        else
        {
           delete f;
           f = NULL;
           throw Exception("Cannot open key to write");
        }

    }

    delete f;
    f = NULL;

    return ok;
}


bool __fastcall TRsRegistry::WriteInteger(int value)
{
    //TODO: Add your source code here
    TRegIniFile *f = new TRegIniFile("");
    bool ok =false;

     if (f->OpenKey(FBaseKey ,!FDontCreate))
     {

         try
         {
           f->WriteInteger( FTargetKey , FTargetValue , value);
           ok = true;
         }
         catch (Exception &e)
         {
            if (FOnReadError)
               FOnReadError(this);
            else
            {
               delete f;
               f = NULL;
               throw e;
            }
         }
    }
    else
    {
        if (FOnReadError)
           FOnReadError(this);
        else
        {
           delete f;
           f = NULL;
           throw Exception("Cannot open key to write");
        }

    }

    delete f;
    f = NULL;

    return ok;
}
